==> ews-javascript-api-0.1.2.tgz: package/js/PropertyDefinitions/TypedPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
var PropertyDefinition_1 = require("./PropertyDefinition");
var TypedPropertyDefinition = (function (_super) {
    __extends(TypedPropertyDefinition, _super);
    function TypedPropertyDefinition(propertyName, xmlElementName, version, uri, flags, isNullable) {
        if (isNullable === void 0) { isNullable = true; }
        _super.call(this, propertyName, xmlElementName, version, uri, flags);
        this.isNullable = isNullable;
    }
    Object.defineProperty(TypedPropertyDefinition.prototype, "IsNullable", {
        get: function () { return this.isNullable; },
        enumerable: true,
        configurable: true
    });
    ;
    TypedPropertyDefinition.prototype.LoadPropertyValueFromJson = function (value, service, propertyBag) { throw new Error("TypedPropertyDefinition.ts - LoadPropertyValueFromJson : Not implemented."); };
    TypedPropertyDefinition.prototype.LoadPropertyValueFromXmlJsObject = function (jsObject, service, propertyBag) {
        var stringValue = jsObject;
        if (typeof jsObject === 'string' || jsObject instanceof String) {
            propertyBag._setItem(this, this.Parse(jsObject));
        }
        else if (jsObject != null) {
            propertyBag._setItem(this, this.Parse(jsObject));
        }
    };
    TypedPropertyDefinition.prototype.Parse = function (value) { throw new Error("abstract TypedPropertyDefinition.ts - Parse : Not implemented."); };
    TypedPropertyDefinition.prototype.ToString = function (value) {
        if (value)
            return value.toString();
        throw new Error("TypedPropertydefinition: incorrect call of ToString()");
    };
    TypedPropertyDefinition.prototype.WritePropertyValueToXml = function (writer, propertyBag, isUpdateOperation) {
        var value = propertyBag._getItem(this);
        if (value != null) {
            writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, this.XmlElementName, value, this.Name);
        }
    };
    return TypedPropertyDefinition;
})(PropertyDefinition_1.PropertyDefinition);
exports.TypedPropertyDefinition = TypedPropertyDefinition;

==> ews-javascript-api-0.1.11.tgz: package/js/PropertyDefinitions/TypedPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
var PropertyDefinition_1 = require("./PropertyDefinition");
var TypedPropertyDefinition = (function (_super) {
    __extends(TypedPropertyDefinition, _super);
    function TypedPropertyDefinition(propertyName, xmlElementName, version, uri, flags, isNullable) {
        if (isNullable === void 0) { isNullable = true; }
        _super.call(this, propertyName, xmlElementName, version, uri, flags);
        this.isNullable = isNullable;
    }
    Object.defineProperty(TypedPropertyDefinition.prototype, "IsNullable", {
        get: function () { return this.isNullable; },
        enumerable: true,
        configurable: true
    });
    ;
    TypedPropertyDefinition.prototype.LoadPropertyValueFromJson = function (value, service, propertyBag) { throw new Error("TypedPropertyDefinition.ts - LoadPropertyValueFromJson : Not implemented."); };
    TypedPropertyDefinition.prototype.LoadPropertyValueFromXmlJsObject = function (jsObject, service, propertyBag) {
        var stringValue = jsObject;
        if (typeof jsObject === 'string' || jsObject instanceof String) {
            propertyBag._setItem(this, this.Parse(jsObject));
        }
        else if (jsObject != null) {
            propertyBag._setItem(this, this.Parse(jsObject));
        }
    };
    TypedPropertyDefinition.prototype.Parse = function (value) { throw new Error("abstract TypedPropertyDefinition.ts - Parse : Not implemented."); };
    TypedPropertyDefinition.prototype.ToString = function (value) {
        if (value)
            return value.toString();
        throw new Error("TypedPropertydefinition: incorrect call of ToString()");
    };
    TypedPropertyDefinition.prototype.WritePropertyValueToXml = function (writer, propertyBag, isUpdateOperation) {
        var value = propertyBag._getItem(this);
        if (value != null) {
            writer.WriteElementValue(XmlNamespace_1.XmlNamespace.Types, this.XmlElementName, this.Name, value);
        }
    };
    return TypedPropertyDefinition;
})(PropertyDefinition_1.PropertyDefinition);
exports.TypedPropertyDefinition = TypedPropertyDefinition;
